@@ -36,12 +36,12 @@ class TransformClient(NamespacedClient):
         force: t.Optional[bool] = None,
         human: t.Optional[bool] = None,
         pretty: t.Optional[bool] = None,
-        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Deletes an existing transform.
+        Deletes a transform.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/delete-transform.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/delete-transform.html>`_
 
         :param transform_id: Identifier for the transform.
         :param delete_dest_index: If this value is true, the destination index is deleted
@@ -101,7 +101,7 @@ class TransformClient(NamespacedClient):
         """
         Retrieves configuration information for transforms.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/get-transform.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/get-transform.html>`_
 
         :param transform_id: Identifier for the transform. It can be a transform identifier
             or a wildcard expression. You can get information for all transforms by using
@@ -165,12 +165,12 @@ class TransformClient(NamespacedClient):
         human: t.Optional[bool] = None,
         pretty: t.Optional[bool] = None,
         size: t.Optional[int] = None,
-        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
         Retrieves usage information for transforms.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/get-transform-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/get-transform-stats.html>`_
 
         :param transform_id: Identifier for the transform. It can be a transform identifier
             or a wildcard expression. You can get information for all transforms by using
@@ -236,7 +236,7 @@ class TransformClient(NamespacedClient):
         dest: t.Optional[t.Mapping[str, t.Any]] = None,
         error_trace: t.Optional[bool] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
-        frequency: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        frequency: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         human: t.Optional[bool] = None,
         latest: t.Optional[t.Mapping[str, t.Any]] = None,
         pivot: t.Optional[t.Mapping[str, t.Any]] = None,
@@ -245,13 +245,16 @@ class TransformClient(NamespacedClient):
         settings: t.Optional[t.Mapping[str, t.Any]] = None,
         source: t.Optional[t.Mapping[str, t.Any]] = None,
         sync: t.Optional[t.Mapping[str, t.Any]] = None,
-        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Previews a transform.
+        Previews a transform. It returns a maximum of 100 results. The calculations are
+        based on all the current data in the source index. It also generates a list of
+        mappings and settings for the destination index. These values are determined
+        based on the field types of the source index and the transform aggregations.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/preview-transform.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/preview-transform.html>`_
 
         :param transform_id: Identifier for the transform to preview. If you specify
             this path parameter, you cannot provide transform configuration details in
@@ -353,7 +356,7 @@ class TransformClient(NamespacedClient):
         description: t.Optional[str] = None,
         error_trace: t.Optional[bool] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
-        frequency: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        frequency: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         human: t.Optional[bool] = None,
         latest: t.Optional[t.Mapping[str, t.Any]] = None,
         meta: t.Optional[t.Mapping[str, t.Any]] = None,
@@ -362,13 +365,32 @@ class TransformClient(NamespacedClient):
         retention_policy: t.Optional[t.Mapping[str, t.Any]] = None,
         settings: t.Optional[t.Mapping[str, t.Any]] = None,
         sync: t.Optional[t.Mapping[str, t.Any]] = None,
-        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Instantiates a transform.
+        Creates a transform. A transform copies data from source indices, transforms
+        it, and persists it into an entity-centric destination index. You can also think
+        of the destination index as a two-dimensional tabular data structure (known as
+        a data frame). The ID for each document in the data frame is generated from a
+        hash of the entity, so there is a unique row per entity. You must choose either
+        the latest or pivot method for your transform; you cannot use both in a single
+        transform. If you choose to use the pivot method for your transform, the entities
+        are defined by the set of `group_by` fields in the pivot object. If you choose
+        to use the latest method, the entities are defined by the `unique_key` field
+        values in the latest object. You must have `create_index`, `index`, and `read`
+        privileges on the destination index and `read` and `view_index_metadata` privileges
+        on the source indices. When Elasticsearch security features are enabled, the
+        transform remembers which roles the user that created it had at the time of creation
+        and uses those same roles. If those roles do not have the required privileges
+        on the source and destination indices, the transform fails when it attempts unauthorized
+        operations. NOTE: You must use Kibana or this API to create a transform. Do not
+        add a transform directly into any `.transform-internal*` indices using the Elasticsearch
+        index API. If Elasticsearch security features are enabled, do not give users
+        any privileges on `.transform-internal*` indices. If you used transforms prior
+        to 7.5, also do not give users any privileges on `.data-frame-internal*` indices.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/put-transform.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/put-transform.html>`_
 
         :param transform_id: Identifier for the transform. This identifier can contain
             lowercase alphanumeric characters (a-z and 0-9), hyphens, and underscores.
@@ -466,9 +488,11 @@ class TransformClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Resets an existing transform.
+        Resets a transform. Before you can reset it, you must stop it; alternatively,
+        use the `force` query parameter. If the destination index was created by the
+        transform, it is deleted.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/reset-transform.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/reset-transform.html>`_
 
         :param transform_id: Identifier for the transform. This identifier can contain
             lowercase alphanumeric characters (a-z and 0-9), hyphens, and underscores.
@@ -511,12 +535,15 @@ class TransformClient(NamespacedClient):
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
         pretty: t.Optional[bool] = None,
-        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Schedules now a transform.
+        Schedules now a transform. If you _schedule_now a transform, it will process
+        the new data instantly, without waiting for the configured frequency interval.
+        After _schedule_now API is called, the transform will be processed again at now
+        + frequency unless _schedule_now API is called again in the meantime.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/schedule-now-transform.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/schedule-now-transform.html>`_
 
         :param transform_id: Identifier for the transform.
         :param timeout: Controls the time to wait for the scheduling to take place
@@ -558,12 +585,28 @@ class TransformClient(NamespacedClient):
         from_: t.Optional[str] = None,
         human: t.Optional[bool] = None,
         pretty: t.Optional[bool] = None,
-        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Starts one or more transforms.
+        Starts a transform. When you start a transform, it creates the destination index
+        if it does not already exist. The `number_of_shards` is set to `1` and the `auto_expand_replicas`
+        is set to `0-1`. If it is a pivot transform, it deduces the mapping definitions
+        for the destination index from the source indices and the transform aggregations.
+        If fields in the destination index are derived from scripts (as in the case of
+        `scripted_metric` or `bucket_script` aggregations), the transform uses dynamic
+        mappings unless an index template exists. If it is a latest transform, it does
+        not deduce mapping definitions; it uses dynamic mappings. To use explicit mappings,
+        create the destination index before you start the transform. Alternatively, you
+        can create an index template, though it does not affect the deduced mappings
+        in a pivot transform. When the transform starts, a series of validations occur
+        to ensure its success. If you deferred validation when you created the transform,
+        they occur when you start the transform—​with the exception of privilege checks.
+        When Elasticsearch security features are enabled, the transform remembers which
+        roles the user that created it had at the time of creation and uses those same
+        roles. If those roles do not have the required privileges on the source and destination
+        indices, the transform fails when it attempts unauthorized operations.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/start-transform.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/start-transform.html>`_
 
         :param transform_id: Identifier for the transform.
         :param from_: Restricts the set of transformed entities to those changed after
@@ -610,14 +653,14 @@ class TransformClient(NamespacedClient):
         force: t.Optional[bool] = None,
         human: t.Optional[bool] = None,
         pretty: t.Optional[bool] = None,
-        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         wait_for_checkpoint: t.Optional[bool] = None,
         wait_for_completion: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
         Stops one or more transforms.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/stop-transform.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/stop-transform.html>`_
 
         :param transform_id: Identifier for the transform. To stop multiple transforms,
             use a comma-separated list or a wildcard expression. To stop all transforms,
@@ -696,7 +739,7 @@ class TransformClient(NamespacedClient):
         dest: t.Optional[t.Mapping[str, t.Any]] = None,
         error_trace: t.Optional[bool] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
-        frequency: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        frequency: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         human: t.Optional[bool] = None,
         meta: t.Optional[t.Mapping[str, t.Any]] = None,
         pretty: t.Optional[bool] = None,
@@ -704,13 +747,19 @@ class TransformClient(NamespacedClient):
         settings: t.Optional[t.Mapping[str, t.Any]] = None,
         source: t.Optional[t.Mapping[str, t.Any]] = None,
         sync: t.Optional[t.Mapping[str, t.Any]] = None,
-        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Updates certain properties of a transform.
+        Updates certain properties of a transform. All updated properties except `description`
+        do not take effect until after the transform starts the next checkpoint, thus
+        there is data consistency in each checkpoint. To use this API, you must have
+        `read` and `view_index_metadata` privileges for the source indices. You must
+        also have `index` and `read` privileges for the destination index. When Elasticsearch
+        security features are enabled, the transform remembers which roles the user who
+        updated it had at the time of update and runs with those privileges.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/update-transform.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/update-transform.html>`_
 
         :param transform_id: Identifier for the transform.
         :param defer_validation: When true, deferrable validations are not run. This
@@ -786,12 +835,18 @@ class TransformClient(NamespacedClient):
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
         pretty: t.Optional[bool] = None,
-        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Upgrades all transforms.
+        Upgrades all transforms. This API identifies transforms that have a legacy configuration
+        format and upgrades them to the latest version. It also cleans up the internal
+        data structures that store the transform state and checkpoints. The upgrade does
+        not affect the source and destination indices. The upgrade also does not affect
+        the roles that transforms use when Elasticsearch security features are enabled;
+        the role used to read source data and write to the destination index remains
+        unchanged.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/upgrade-transforms.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/upgrade-transforms.html>`_
 
         :param dry_run: When true, the request checks for updates but does not run them.
         :param timeout: Period to wait for a response. If no response is received before
