@@ -46,7 +46,7 @@ class ClusterClient(NamespacedClient):
         """
         Provides explanations for shard allocations in the cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/cluster-allocation-explain.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-allocation-explain.html>`_
 
         :param current_node: Specifies the node ID or the name of the node to only explain
             a shard that is currently located on the specified node.
@@ -108,16 +108,15 @@ class ClusterClient(NamespacedClient):
         error_trace: t.Optional[bool] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
-        master_timeout: t.Optional[
-            t.Union["t.Literal[-1]", "t.Literal[0]", str]
-        ] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         pretty: t.Optional[bool] = None,
-        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Deletes a component template
+        Deletes component templates. Component templates are building blocks for constructing
+        index templates that specify index mappings, settings, and aliases.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/indices-component-template.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/indices-component-template.html>`_
 
         :param name: Comma-separated list or wildcard expression of component template
             names used to limit the request.
@@ -167,7 +166,7 @@ class ClusterClient(NamespacedClient):
         """
         Clears cluster voting config exclusions.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/voting-config-exclusions.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/voting-config-exclusions.html>`_
 
         :param wait_for_removal: Specifies whether to wait for all excluded nodes to
             be removed from the cluster before clearing the voting configuration exclusions
@@ -208,15 +207,13 @@ class ClusterClient(NamespacedClient):
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
         local: t.Optional[bool] = None,
-        master_timeout: t.Optional[
-            t.Union["t.Literal[-1]", "t.Literal[0]", str]
-        ] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         pretty: t.Optional[bool] = None,
     ) -> HeadApiResponse:
         """
         Returns information about whether a particular component template exist
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/indices-component-template.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/indices-component-template.html>`_
 
         :param name: Comma-separated list of component template names used to limit the
             request. Wildcard (*) expressions are supported.
@@ -265,15 +262,13 @@ class ClusterClient(NamespacedClient):
         human: t.Optional[bool] = None,
         include_defaults: t.Optional[bool] = None,
         local: t.Optional[bool] = None,
-        master_timeout: t.Optional[
-            t.Union["t.Literal[-1]", "t.Literal[0]", str]
-        ] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns one or more component templates
+        Retrieves information about component templates.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/indices-component-template.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/indices-component-template.html>`_
 
         :param name: Comma-separated list of component template names used to limit the
             request. Wildcard (`*`) expressions are supported.
@@ -329,16 +324,15 @@ class ClusterClient(NamespacedClient):
         flat_settings: t.Optional[bool] = None,
         human: t.Optional[bool] = None,
         include_defaults: t.Optional[bool] = None,
-        master_timeout: t.Optional[
-            t.Union["t.Literal[-1]", "t.Literal[0]", str]
-        ] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         pretty: t.Optional[bool] = None,
-        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns cluster settings.
+        Returns cluster-wide settings. By default, it returns only settings that have
+        been explicitly defined.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/cluster-get-settings.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-get-settings.html>`_
 
         :param flat_settings: If `true`, returns settings in flat format.
         :param include_defaults: If `true`, returns default cluster settings from the
@@ -387,47 +381,53 @@ class ClusterClient(NamespacedClient):
         expand_wildcards: t.Optional[
             t.Union[
                 t.Sequence[
-                    t.Union["t.Literal['all', 'closed', 'hidden', 'none', 'open']", str]
+                    t.Union[str, t.Literal["all", "closed", "hidden", "none", "open"]]
                 ],
-                t.Union["t.Literal['all', 'closed', 'hidden', 'none', 'open']", str],
+                t.Union[str, t.Literal["all", "closed", "hidden", "none", "open"]],
             ]
         ] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
         level: t.Optional[
-            t.Union["t.Literal['cluster', 'indices', 'shards']", str]
+            t.Union[str, t.Literal["cluster", "indices", "shards"]]
         ] = None,
         local: t.Optional[bool] = None,
-        master_timeout: t.Optional[
-            t.Union["t.Literal[-1]", "t.Literal[0]", str]
-        ] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         pretty: t.Optional[bool] = None,
-        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         wait_for_active_shards: t.Optional[
-            t.Union[int, t.Union["t.Literal['all', 'index-setting']", str]]
+            t.Union[int, t.Union[str, t.Literal["all", "index-setting"]]]
         ] = None,
         wait_for_events: t.Optional[
             t.Union[
-                "t.Literal['high', 'immediate', 'languid', 'low', 'normal', 'urgent']",
                 str,
+                t.Literal["high", "immediate", "languid", "low", "normal", "urgent"],
             ]
         ] = None,
         wait_for_no_initializing_shards: t.Optional[bool] = None,
         wait_for_no_relocating_shards: t.Optional[bool] = None,
         wait_for_nodes: t.Optional[t.Union[int, str]] = None,
         wait_for_status: t.Optional[
-            t.Union["t.Literal['green', 'red', 'yellow']", str]
+            t.Union[str, t.Literal["green", "red", "yellow"]]
         ] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns basic information about the health of the cluster.
+        The cluster health API returns a simple status on the health of the cluster.
+        You can also use the API to get the health status of only specified data streams
+        and indices. For data streams, the API retrieves the health status of the stream’s
+        backing indices. The cluster health status is: green, yellow or red. On the shard
+        level, a red status indicates that the specific shard is not allocated in the
+        cluster, yellow means that the primary shard is allocated but replicas are not,
+        and green means that all shards are allocated. The index level status is controlled
+        by the worst shard status. The cluster status is controlled by the worst index
+        status.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/cluster-health.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-health.html>`_
 
         :param index: Comma-separated list of data streams, indices, and index aliases
-            used to limit the request. Wildcard expressions (*) are supported. To target
+            used to limit the request. Wildcard expressions (`*`) are supported. To target
             all data streams and indices in a cluster, omit this parameter or use _all
-            or *.
+            or `*`.
         :param expand_wildcards: Whether to expand wildcard expression to concrete indices
             that are open, closed or both.
         :param level: Can be one of cluster, indices or shards. Controls the details
@@ -513,12 +513,10 @@ class ClusterClient(NamespacedClient):
         target: t.Union[
             t.Sequence[
                 t.Union[
-                    "t.Literal['_all', 'http', 'ingest', 'script', 'thread_pool']", str
+                    str, t.Literal["_all", "http", "ingest", "script", "thread_pool"]
                 ]
             ],
-            t.Union[
-                "t.Literal['_all', 'http', 'ingest', 'script', 'thread_pool']", str
-            ],
+            t.Union[str, t.Literal["_all", "http", "ingest", "script", "thread_pool"]],
         ],
         error_trace: t.Optional[bool] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
@@ -528,7 +526,7 @@ class ClusterClient(NamespacedClient):
         """
         Returns different information about the cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/cluster-info.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-info.html>`_
 
         :param target: Limits the information returned to the specific target. Supports
             a comma-separated list, such as http,ingest.
@@ -564,16 +562,20 @@ class ClusterClient(NamespacedClient):
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
         local: t.Optional[bool] = None,
-        master_timeout: t.Optional[
-            t.Union["t.Literal[-1]", "t.Literal[0]", str]
-        ] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns a list of any cluster-level changes (e.g. create index, update mapping,
-        allocate or fail shard) which have not yet been executed.
+        Returns cluster-level changes (such as create index, update mapping, allocate
+        or fail shard) that have not yet been executed. NOTE: This API returns a list
+        of any pending updates to the cluster state. These are distinct from the tasks
+        reported by the Task Management API which include periodic tasks and tasks initiated
+        by the user, such as node stats, search queries, or create index requests. However,
+        if a user-initiated task such as a create index command causes a cluster state
+        update, the activity of this task might be reported by both task api and pending
+        cluster tasks API.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/cluster-pending.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-pending.html>`_
 
         :param local: If `true`, the request retrieves information from the local node
             only. If `false`, information is retrieved from the master node.
@@ -616,12 +618,12 @@ class ClusterClient(NamespacedClient):
         node_ids: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         node_names: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         pretty: t.Optional[bool] = None,
-        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
         Updates the cluster voting config exclusions by node ids or node names.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/voting-config-exclusions.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/voting-config-exclusions.html>`_
 
         :param node_ids: A comma-separated list of the persistent ids of the nodes to
             exclude from the voting configuration. If specified, you may not also specify
@@ -661,7 +663,7 @@ class ClusterClient(NamespacedClient):
         )
 
     @_rewrite_parameters(
-        body_fields=("template", "allow_auto_create", "meta", "version"),
+        body_fields=("template", "deprecated", "meta", "version"),
         parameter_aliases={"_meta": "meta"},
     )
     def put_component_template(
@@ -669,23 +671,33 @@ class ClusterClient(NamespacedClient):
         *,
         name: str,
         template: t.Optional[t.Mapping[str, t.Any]] = None,
-        allow_auto_create: t.Optional[bool] = None,
         create: t.Optional[bool] = None,
+        deprecated: t.Optional[bool] = None,
         error_trace: t.Optional[bool] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
-        master_timeout: t.Optional[
-            t.Union["t.Literal[-1]", "t.Literal[0]", str]
-        ] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         meta: t.Optional[t.Mapping[str, t.Any]] = None,
         pretty: t.Optional[bool] = None,
         version: t.Optional[int] = None,
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Creates or updates a component template
+        Creates or updates a component template. Component templates are building blocks
+        for constructing index templates that specify index mappings, settings, and aliases.
+        An index template can be composed of multiple component templates. To use a component
+        template, specify it in an index template’s `composed_of` list. Component templates
+        are only applied to new data streams and indices as part of a matching index
+        template. Settings and mappings specified directly in the index template or the
+        create index request override any settings or mappings specified in a component
+        template. Component templates are only used during index creation. For data streams,
+        this includes data stream creation and the creation of a stream’s backing indices.
+        Changes to component templates do not affect existing indices, including a stream’s
+        backing indices. You can use C-style `/* *\\/` block comments in component templates.
+        You can include comments anywhere in the request body except before the opening
+        curly bracket.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/indices-component-template.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/indices-component-template.html>`_
 
         :param name: Name of the component template to create. Elasticsearch includes
             the following built-in component templates: `logs-mappings`; 'logs-settings`;
@@ -698,13 +710,11 @@ class ClusterClient(NamespacedClient):
             update settings API.
         :param template: The template to be applied which includes mappings, settings,
             or aliases configuration.
-        :param allow_auto_create: This setting overrides the value of the `action.auto_create_index`
-            cluster setting. If set to `true` in a template, then indices can be automatically
-            created using that template even if auto-creation of indices is disabled
-            via `actions.auto_create_index`. If set to `false` then data streams matching
-            the template must always be explicitly created.
         :param create: If `true`, this request cannot replace or update existing component
             templates.
+        :param deprecated: Marks this index template as deprecated. When creating or
+            updating a non-deprecated index template that uses deprecated components,
+            Elasticsearch will emit a deprecation warning.
         :param master_timeout: Period to wait for a connection to the master node. If
             no response is received before the timeout expires, the request fails and
             returns an error.
@@ -739,8 +749,8 @@ class ClusterClient(NamespacedClient):
         if not __body:
             if template is not None:
                 __body["template"] = template
-            if allow_auto_create is not None:
-                __body["allow_auto_create"] = allow_auto_create
+            if deprecated is not None:
+                __body["deprecated"] = deprecated
             if meta is not None:
                 __body["_meta"] = meta
             if version is not None:
@@ -766,19 +776,17 @@ class ClusterClient(NamespacedClient):
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         flat_settings: t.Optional[bool] = None,
         human: t.Optional[bool] = None,
-        master_timeout: t.Optional[
-            t.Union["t.Literal[-1]", "t.Literal[0]", str]
-        ] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         persistent: t.Optional[t.Mapping[str, t.Any]] = None,
         pretty: t.Optional[bool] = None,
-        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         transient: t.Optional[t.Mapping[str, t.Any]] = None,
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
         Updates the cluster settings.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/cluster-update-settings.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-update-settings.html>`_
 
         :param flat_settings: Return settings in flat format (default: false)
         :param master_timeout: Explicit operation timeout for connection to master node
@@ -830,9 +838,11 @@ class ClusterClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns the information about configured remote clusters.
+        The cluster remote info API allows you to retrieve all of the configured remote
+        cluster information. It returns connection and endpoint information keyed by
+        the configured remote cluster alias.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/cluster-remote-info.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-remote-info.html>`_
         """
         __path_parts: t.Dict[str, str] = {}
         __path = "/_remote/info"
@@ -867,19 +877,17 @@ class ClusterClient(NamespacedClient):
         explain: t.Optional[bool] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
-        master_timeout: t.Optional[
-            t.Union["t.Literal[-1]", "t.Literal[0]", str]
-        ] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         metric: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         pretty: t.Optional[bool] = None,
         retry_failed: t.Optional[bool] = None,
-        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
         Allows to manually change the allocation of individual shards in the cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/cluster-reroute.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-reroute.html>`_
 
         :param commands: Defines the commands to perform.
         :param dry_run: If true, then the request simulates the operation only and returns
@@ -948,9 +956,9 @@ class ClusterClient(NamespacedClient):
         expand_wildcards: t.Optional[
             t.Union[
                 t.Sequence[
-                    t.Union["t.Literal['all', 'closed', 'hidden', 'none', 'open']", str]
+                    t.Union[str, t.Literal["all", "closed", "hidden", "none", "open"]]
                 ],
-                t.Union["t.Literal['all', 'closed', 'hidden', 'none', 'open']", str],
+                t.Union[str, t.Literal["all", "closed", "hidden", "none", "open"]],
             ]
         ] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
@@ -958,19 +966,15 @@ class ClusterClient(NamespacedClient):
         human: t.Optional[bool] = None,
         ignore_unavailable: t.Optional[bool] = None,
         local: t.Optional[bool] = None,
-        master_timeout: t.Optional[
-            t.Union["t.Literal[-1]", "t.Literal[0]", str]
-        ] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         pretty: t.Optional[bool] = None,
         wait_for_metadata_version: t.Optional[int] = None,
-        wait_for_timeout: t.Optional[
-            t.Union["t.Literal[-1]", "t.Literal[0]", str]
-        ] = None,
+        wait_for_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
         Returns a comprehensive information about the state of the cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/cluster-state.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-state.html>`_
 
         :param metric: Limit the information returned to the specified metrics
         :param index: A comma-separated list of index names; use `_all` or empty string
@@ -1049,12 +1053,14 @@ class ClusterClient(NamespacedClient):
         flat_settings: t.Optional[bool] = None,
         human: t.Optional[bool] = None,
         pretty: t.Optional[bool] = None,
-        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns high-level overview of cluster statistics.
+        Returns cluster statistics. It returns basic index metrics (shard numbers, store
+        size, memory usage) and information about the current nodes that form the cluster
+        (number, roles, os, jvm versions, memory usage, cpu and installed plugins).
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/cluster-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-stats.html>`_
 
         :param node_id: Comma-separated list of node filters used to limit returned information.
             Defaults to all nodes in the cluster.
