@@ -25,6 +25,57 @@ from .utils import SKIP_IN_PATH, _quote, _rewrite_parameters
 
 class IngestClient(NamespacedClient):
 
+    @_rewrite_parameters()
+    def delete_geoip_database(
+        self,
+        *,
+        id: t.Union[str, t.Sequence[str]],
+        error_trace: t.Optional[bool] = None,
+        filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
+        human: t.Optional[bool] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
+        pretty: t.Optional[bool] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
+    ) -> ObjectApiResponse[t.Any]:
+        """
+        Deletes a geoip database configuration.
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/TODO.html>`_
+
+        :param id: A comma-separated list of geoip database configurations to delete
+        :param master_timeout: Period to wait for a connection to the master node. If
+            no response is received before the timeout expires, the request fails and
+            returns an error.
+        :param timeout: Period to wait for a response. If no response is received before
+            the timeout expires, the request fails and returns an error.
+        """
+        if id in SKIP_IN_PATH:
+            raise ValueError("Empty value passed for parameter 'id'")
+        __path_parts: t.Dict[str, str] = {"id": _quote(id)}
+        __path = f'/_ingest/geoip/database/{__path_parts["id"]}'
+        __query: t.Dict[str, t.Any] = {}
+        if error_trace is not None:
+            __query["error_trace"] = error_trace
+        if filter_path is not None:
+            __query["filter_path"] = filter_path
+        if human is not None:
+            __query["human"] = human
+        if master_timeout is not None:
+            __query["master_timeout"] = master_timeout
+        if pretty is not None:
+            __query["pretty"] = pretty
+        if timeout is not None:
+            __query["timeout"] = timeout
+        __headers = {"accept": "application/json"}
+        return self.perform_request(  # type: ignore[return-value]
+            "DELETE",
+            __path,
+            params=__query,
+            headers=__headers,
+            endpoint_id="ingest.delete_geoip_database",
+            path_parts=__path_parts,
+        )
+
     @_rewrite_parameters()
     def delete_pipeline(
         self,
@@ -33,16 +84,14 @@ class IngestClient(NamespacedClient):
         error_trace: t.Optional[bool] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
-        master_timeout: t.Optional[
-            t.Union["t.Literal[-1]", "t.Literal[0]", str]
-        ] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         pretty: t.Optional[bool] = None,
-        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Deletes a pipeline.
+        Deletes one or more existing ingest pipeline.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.14/delete-pipeline-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/delete-pipeline-api.html>`_
 
         :param id: Pipeline ID or wildcard expression of pipeline IDs used to limit the
             request. To delete all ingest pipelines in a cluster, use a value of `*`.
@@ -89,9 +138,9 @@ class IngestClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns statistical information about geoip databases
+        Gets download statistics for GeoIP2 databases used with the geoip processor.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.14/geoip-processor.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/geoip-processor.html>`_
         """
         __path_parts: t.Dict[str, str] = {}
         __path = "/_ingest/geoip/stats"
@@ -114,6 +163,57 @@ class IngestClient(NamespacedClient):
             path_parts=__path_parts,
         )
 
+    @_rewrite_parameters()
+    def get_geoip_database(
+        self,
+        *,
+        id: t.Optional[t.Union[str, t.Sequence[str]]] = None,
+        error_trace: t.Optional[bool] = None,
+        filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
+        human: t.Optional[bool] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
+        pretty: t.Optional[bool] = None,
+    ) -> ObjectApiResponse[t.Any]:
+        """
+        Returns information about one or more geoip database configurations.
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/TODO.html>`_
+
+        :param id: Comma-separated list of database configuration IDs to retrieve. Wildcard
+            (`*`) expressions are supported. To get all database configurations, omit
+            this parameter or use `*`.
+        :param master_timeout: Period to wait for a connection to the master node. If
+            no response is received before the timeout expires, the request fails and
+            returns an error.
+        """
+        __path_parts: t.Dict[str, str]
+        if id not in SKIP_IN_PATH:
+            __path_parts = {"id": _quote(id)}
+            __path = f'/_ingest/geoip/database/{__path_parts["id"]}'
+        else:
+            __path_parts = {}
+            __path = "/_ingest/geoip/database"
+        __query: t.Dict[str, t.Any] = {}
+        if error_trace is not None:
+            __query["error_trace"] = error_trace
+        if filter_path is not None:
+            __query["filter_path"] = filter_path
+        if human is not None:
+            __query["human"] = human
+        if master_timeout is not None:
+            __query["master_timeout"] = master_timeout
+        if pretty is not None:
+            __query["pretty"] = pretty
+        __headers = {"accept": "application/json"}
+        return self.perform_request(  # type: ignore[return-value]
+            "GET",
+            __path,
+            params=__query,
+            headers=__headers,
+            endpoint_id="ingest.get_geoip_database",
+            path_parts=__path_parts,
+        )
+
     @_rewrite_parameters()
     def get_pipeline(
         self,
@@ -122,16 +222,15 @@ class IngestClient(NamespacedClient):
         error_trace: t.Optional[bool] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
-        master_timeout: t.Optional[
-            t.Union["t.Literal[-1]", "t.Literal[0]", str]
-        ] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         pretty: t.Optional[bool] = None,
         summary: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns a pipeline.
+        Returns information about one or more ingest pipelines. This API returns a local
+        reference of the pipeline.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.14/get-pipeline-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/get-pipeline-api.html>`_
 
         :param id: Comma-separated list of pipeline IDs to retrieve. Wildcard (`*`) expressions
             are supported. To get all ingest pipelines, omit this parameter or use `*`.
@@ -180,9 +279,12 @@ class IngestClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns a list of the built-in patterns.
+        Extracts structured fields out of a single text field within a document. You
+        choose which field to extract matched fields from, as well as the grok pattern
+        you expect will match. A grok pattern is like a regular expression that supports
+        aliased expressions that can be reused.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.14/grok-processor.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/grok-processor.html>`_
         """
         __path_parts: t.Dict[str, str] = {}
         __path = "/_ingest/processor/grok"
@@ -205,6 +307,79 @@ class IngestClient(NamespacedClient):
             path_parts=__path_parts,
         )
 
+    @_rewrite_parameters(
+        body_fields=("maxmind", "name"),
+    )
+    def put_geoip_database(
+        self,
+        *,
+        id: str,
+        maxmind: t.Optional[t.Mapping[str, t.Any]] = None,
+        name: t.Optional[str] = None,
+        error_trace: t.Optional[bool] = None,
+        filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
+        human: t.Optional[bool] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
+        pretty: t.Optional[bool] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
+        body: t.Optional[t.Dict[str, t.Any]] = None,
+    ) -> ObjectApiResponse[t.Any]:
+        """
+        Returns information about one or more geoip database configurations.
+
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/TODO.html>`_
+
+        :param id: ID of the database configuration to create or update.
+        :param maxmind: The configuration necessary to identify which IP geolocation
+            provider to use to download the database, as well as any provider-specific
+            configuration necessary for such downloading. At present, the only supported
+            provider is maxmind, and the maxmind provider requires that an account_id
+            (string) is configured.
+        :param name: The provider-assigned name of the IP geolocation database to download.
+        :param master_timeout: Period to wait for a connection to the master node. If
+            no response is received before the timeout expires, the request fails and
+            returns an error.
+        :param timeout: Period to wait for a response. If no response is received before
+            the timeout expires, the request fails and returns an error.
+        """
+        if id in SKIP_IN_PATH:
+            raise ValueError("Empty value passed for parameter 'id'")
+        if maxmind is None and body is None:
+            raise ValueError("Empty value passed for parameter 'maxmind'")
+        if name is None and body is None:
+            raise ValueError("Empty value passed for parameter 'name'")
+        __path_parts: t.Dict[str, str] = {"id": _quote(id)}
+        __path = f'/_ingest/geoip/database/{__path_parts["id"]}'
+        __query: t.Dict[str, t.Any] = {}
+        __body: t.Dict[str, t.Any] = body if body is not None else {}
+        if error_trace is not None:
+            __query["error_trace"] = error_trace
+        if filter_path is not None:
+            __query["filter_path"] = filter_path
+        if human is not None:
+            __query["human"] = human
+        if master_timeout is not None:
+            __query["master_timeout"] = master_timeout
+        if pretty is not None:
+            __query["pretty"] = pretty
+        if timeout is not None:
+            __query["timeout"] = timeout
+        if not __body:
+            if maxmind is not None:
+                __body["maxmind"] = maxmind
+            if name is not None:
+                __body["name"] = name
+        __headers = {"accept": "application/json", "content-type": "application/json"}
+        return self.perform_request(  # type: ignore[return-value]
+            "PUT",
+            __path,
+            params=__query,
+            headers=__headers,
+            body=__body,
+            endpoint_id="ingest.put_geoip_database",
+            path_parts=__path_parts,
+        )
+
     @_rewrite_parameters(
         body_fields=("description", "meta", "on_failure", "processors", "version"),
         parameter_aliases={"_meta": "meta"},
@@ -218,21 +393,20 @@ class IngestClient(NamespacedClient):
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
         if_version: t.Optional[int] = None,
-        master_timeout: t.Optional[
-            t.Union["t.Literal[-1]", "t.Literal[0]", str]
-        ] = None,
+        master_timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         meta: t.Optional[t.Mapping[str, t.Any]] = None,
         on_failure: t.Optional[t.Sequence[t.Mapping[str, t.Any]]] = None,
         pretty: t.Optional[bool] = None,
         processors: t.Optional[t.Sequence[t.Mapping[str, t.Any]]] = None,
-        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         version: t.Optional[int] = None,
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Creates or updates a pipeline.
+        Creates or updates an ingest pipeline. Changes made using this API take effect
+        immediately.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.14/ingest.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/ingest.html>`_
 
         :param id: ID of the ingest pipeline to create or update.
         :param description: Description of the ingest pipeline.
@@ -316,9 +490,9 @@ class IngestClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Allows to simulate a pipeline with example documents.
+        Executes an ingest pipeline against a set of provided documents.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.14/simulate-pipeline-api.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/simulate-pipeline-api.html>`_
 
         :param id: Pipeline to test. If you don’t specify a `pipeline` in the request
             body, this parameter is required.
