@@ -38,7 +38,7 @@ class SynonymsClient(NamespacedClient):
         """
         Deletes a synonym set
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.14/delete-synonyms-set.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/delete-synonyms-set.html>`_
 
         :param id: The id of the synonyms set to be deleted
         """
@@ -79,7 +79,7 @@ class SynonymsClient(NamespacedClient):
         """
         Deletes a synonym rule in a synonym set
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.14/delete-synonym-rule.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/delete-synonym-rule.html>`_
 
         :param set_id: The id of the synonym set to be updated
         :param rule_id: The id of the synonym rule to be deleted
@@ -129,7 +129,7 @@ class SynonymsClient(NamespacedClient):
         """
         Retrieves a synonym set
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.14/get-synonyms-set.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/get-synonyms-set.html>`_
 
         :param id: "The id of the synonyms set to be retrieved
         :param from_: Starting offset for query rules to be retrieved
@@ -176,7 +176,7 @@ class SynonymsClient(NamespacedClient):
         """
         Retrieves a synonym rule from a synonym set
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.14/get-synonym-rule.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/get-synonym-rule.html>`_
 
         :param set_id: The id of the synonym set to retrieve the synonym rule from
         :param rule_id: The id of the synonym rule to retrieve
@@ -225,7 +225,7 @@ class SynonymsClient(NamespacedClient):
         """
         Retrieves a summary of all defined synonym sets
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.14/list-synonyms-sets.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/list-synonyms-sets.html>`_
 
         :param from_: Starting offset
         :param size: specifies a max number of results to get
@@ -262,7 +262,9 @@ class SynonymsClient(NamespacedClient):
         self,
         *,
         id: str,
-        synonyms_set: t.Optional[t.Sequence[t.Mapping[str, t.Any]]] = None,
+        synonyms_set: t.Optional[
+            t.Union[t.Mapping[str, t.Any], t.Sequence[t.Mapping[str, t.Any]]]
+        ] = None,
         error_trace: t.Optional[bool] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
@@ -270,9 +272,9 @@ class SynonymsClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Creates or updates a synonyms set
+        Creates or updates a synonym set.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.14/put-synonyms-set.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/put-synonyms-set.html>`_
 
         :param id: The id of the synonyms set to be created or updated
         :param synonyms_set: The synonym set information to update
@@ -325,7 +327,7 @@ class SynonymsClient(NamespacedClient):
         """
         Creates or updates a synonym rule in a synonym set
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.14/put-synonym-rule.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/put-synonym-rule.html>`_
 
         :param set_id: The id of the synonym set to be updated with the synonym rule
         :param rule_id: The id of the synonym rule to be updated or created
