@@ -39,7 +39,7 @@ class WatcherClient(NamespacedClient):
         """
         Acknowledges a watch, manually throttling the execution of the watch's actions.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/watcher-api-ack-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/watcher-api-ack-watch.html>`_
 
         :param watch_id: Watch ID
         :param action_id: A comma-separated list of the action ids to be acked
@@ -90,7 +90,7 @@ class WatcherClient(NamespacedClient):
         """
         Activates a currently inactive watch.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/watcher-api-activate-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/watcher-api-activate-watch.html>`_
 
         :param watch_id: Watch ID
         """
@@ -130,7 +130,7 @@ class WatcherClient(NamespacedClient):
         """
         Deactivates a currently active watch.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/watcher-api-deactivate-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/watcher-api-deactivate-watch.html>`_
 
         :param watch_id: Watch ID
         """
@@ -170,7 +170,7 @@ class WatcherClient(NamespacedClient):
         """
         Removes a watch from Watcher.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/watcher-api-delete-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/watcher-api-delete-watch.html>`_
 
         :param id: Watch ID
         """
@@ -216,8 +216,10 @@ class WatcherClient(NamespacedClient):
             t.Mapping[
                 str,
                 t.Union[
-                    "t.Literal['execute', 'force_execute', 'force_simulate', 'simulate', 'skip']",
                     str,
+                    t.Literal[
+                        "execute", "force_execute", "force_simulate", "simulate", "skip"
+                    ],
                 ],
             ]
         ] = None,
@@ -235,9 +237,15 @@ class WatcherClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Forces the execution of a stored watch.
+        This API can be used to force execution of the watch outside of its triggering
+        logic or to simulate the watch execution for debugging purposes. For testing
+        and debugging purposes, you also have fine-grained control on how the watch runs.
+        You can execute the watch without executing all of its actions or alternatively
+        by simulating them. You can also force execution by ignoring the watch condition
+        and control whether a watch record would be written to the watch history after
+        execution.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/watcher-api-execute-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/watcher-api-execute-watch.html>`_
 
         :param id: Identifier for the watch.
         :param action_modes: Determines how to handle the watch actions as part of the
@@ -320,7 +328,7 @@ class WatcherClient(NamespacedClient):
         """
         Retrieves a watch by its ID.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/watcher-api-get-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/watcher-api-get-watch.html>`_
 
         :param id: Watch ID
         """
@@ -382,7 +390,7 @@ class WatcherClient(NamespacedClient):
         """
         Creates a new watch, or updates an existing one.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/watcher-api-put-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/watcher-api-put-watch.html>`_
 
         :param id: Watch ID
         :param actions:
@@ -479,7 +487,7 @@ class WatcherClient(NamespacedClient):
         """
         Retrieves stored watches.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/watcher-api-query-watches.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/watcher-api-query-watches.html>`_
 
         :param from_: The offset from the first result to fetch. Needs to be non-negative.
         :param query: Optional, query filter watches to be returned.
@@ -549,7 +557,7 @@ class WatcherClient(NamespacedClient):
         """
         Starts Watcher if it is not already running.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/watcher-api-start.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/watcher-api-start.html>`_
         """
         __path_parts: t.Dict[str, str] = {}
         __path = "/_watcher/_start"
@@ -580,13 +588,20 @@ class WatcherClient(NamespacedClient):
             t.Union[
                 t.Sequence[
                     t.Union[
-                        "t.Literal['_all', 'current_watches', 'pending_watches', 'queued_watches']",
                         str,
+                        t.Literal[
+                            "_all",
+                            "current_watches",
+                            "pending_watches",
+                            "queued_watches",
+                        ],
                     ]
                 ],
                 t.Union[
-                    "t.Literal['_all', 'current_watches', 'pending_watches', 'queued_watches']",
                     str,
+                    t.Literal[
+                        "_all", "current_watches", "pending_watches", "queued_watches"
+                    ],
                 ],
             ]
         ] = None,
@@ -599,7 +614,7 @@ class WatcherClient(NamespacedClient):
         """
         Retrieves the current Watcher metrics.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/watcher-api-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/watcher-api-stats.html>`_
 
         :param metric: Defines which additional metrics are included in the response.
         :param emit_stacktraces: Defines whether stack traces are generated for each
@@ -645,7 +660,7 @@ class WatcherClient(NamespacedClient):
         """
         Stops Watcher if it is running.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.13/watcher-api-stop.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/watcher-api-stop.html>`_
         """
         __path_parts: t.Dict[str, str] = {}
         __path = "/_watcher/_stop"
